@@ -38,7 +38,7 @@ static DirtyCallbackFunc parent_dirty_cb;
 /* table widget callback prototypes */
 static void remove_cb (GtkWidget *widget);
 static void selection_changed (GtkTreeSelection *selection);
-static void dirty_cb (GtkWidget *widget);
+static void session_properties_dirty_cb (GtkWidget *widget);
 
 static GtkWidget*
 create_table (void)
@@ -64,7 +64,7 @@ create_table (void)
 		   "changed", G_CALLBACK (selection_changed),
 		   client_list);
   gtk_signal_connect(GTK_OBJECT(client_list), "dirty",
-		     GTK_SIGNAL_FUNC (dirty_cb), NULL);
+		     GTK_SIGNAL_FUNC (session_properties_dirty_cb), NULL);
 
   client_editor = gsm_client_list_get_editor (GSM_CLIENT_LIST (client_list));
 
@@ -84,8 +84,6 @@ create_table (void)
   gtk_box_pack_start (GTK_BOX (hbox), remove_button, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), apply_button, FALSE, FALSE, 0);
   
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-
   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
   label = gtk_label_new_with_mnemonic (_("Currently running _programs:"));
   gtk_container_add (GTK_CONTAINER (alignment), label);
@@ -93,6 +91,8 @@ create_table (void)
   
   gtk_box_pack_start (GTK_BOX (vbox), scrolled_window, TRUE, TRUE, 0);
 
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), client_list);
 
   return vbox;
@@ -145,7 +145,7 @@ selection_changed (GtkTreeSelection *selection)
 
 /* This is called when an change is made in the client list.  */
 static void
-dirty_cb (GtkWidget *widget)
+session_properties_dirty_cb (GtkWidget *widget)
 {
   parent_dirty_cb ();
 }
